@@ -73,7 +73,6 @@ c----       include '../Zcode.h'
        record /ptcl/ p
        integer code, charge, subcode
 c
-
           p.code = code
 c          if(code .ge. kdeut .and. code .le. khvymax) then
           if(code .ge. kalfa .and. code .le. khvymax) then
@@ -181,13 +180,18 @@ c             binding energy. (Weizsacker-Bethe)
      *            -(15.68d-3*subcode-18.56d-3*(float(subcode))**0.6666
      *          -0.717d-3 * charge**2/(float(subcode))**0.33333)
        elseif(code .ge. 0 .and. code .le. klast) then
-            p.mass = mass(code, charge)
-            if(p.mass .eq. x) then
-               call cgpid(code, id)
-               write(msg, *)
-     *        ' charge=',charge,' invalid for csmass; code=',id
-               call cerrorMsg(msg, 0)
-            endif
+          p.mass = mass(code, charge)
+          if(p.mass .eq. x) then
+             call cgpid(code, id)
+             write(msg, *)
+     *            ' charge=',charge,' invalid for csmass; code=',id
+             call cerrorMsg(msg, 0)
+          endif
+       elseif( code .eq. klight ) then
+          p.mass = 0.
+       elseif( code .eq. kEdepo .or. code .eq. kchgPath ) then
+c         energy deposit or charged ptcl streight path for
+c         light emission; nothing to do
        else
             write(msg, *) ' code=',code,' invalid to csmass'
             call cerrorMsg(msg, 0)
@@ -284,6 +288,10 @@ c             p.subcode = isign(1, charge) *regptcl
           else      
              p.subcode = 0      ! should be fixed later
           endif     
+       elseif( code .eq. klight .or. code .eq. kEdepo .or.
+     *         code .eq. kchgPath ) then
+c                not certain. 
+          p.subcode = subcode
        elseif(code .eq. krare) then
           p.subcode = 0
        else     
@@ -369,9 +377,11 @@ c
      *        ida(kphi)/'Phi'/,  ida(kgnuc)/'Nucleus'/
 c     *        ida(kphi)/'Phi'/,  ida(kdeut)/'deuteron'/
 c                heavy neucleus
-         data ida(kalfa)/'Helium'/, ida(klibe)/'LiBiB'/,
+         data ida(kalfa)/'Helium'/, ida(klibe)/'LiBeB'/,
      *        ida(kcno)/'CNO'/, ida(khvy)/'NaMgSi'/,
-     *        ida(kvhvy)/'SClAr'/, ida(kiron)/'Fe'/
+     *        ida(kvhvy)/'SClAr'/, ida(kiron)/'Fe'/,
+     *        ida(keta+1)/'light'/, ida(keta+2)/'dE'/,
+     *        ida(keta+2)/'cpath'/
          data ida(ksigma)/'sigma'/, ida(klambda)/'lambda'/,
      *   ida(kgzai)/'gzai'/, ida(klambdac)/'lambdac'/,
      *   ida(kbomega)/'Omega'/
