@@ -4,6 +4,42 @@ c
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
+#include "Zmass.h"
+#include "Zevhnp.h"
+      record /ptcl/pj   !input projectile particle
+      real(8),intent(in)::  A          ! input. effective target mass number
+      real(8),intent(out):: xs          ! output. in mb. total xsection. 
+c           ctotx0 gives small Xs so we renormalize by
+c           using cPDGsigmaTotpA(A) at @200 GeV 
+      real(8):: cPDGsigmaTotpA
+      record /ptcl/ proton
+      save proton
+      real(8),save:: xst
+      logical,save::first=.true. 
+      real(8),save::Asave=-1.
+      real(8),save::ratio
+
+
+      call ctotx0(pj, A, xs)
+      if( A /= 1.0d0 ) then 
+         if(first) then
+            call cmkptc(knuc, -1, 1, proton)
+            proton.fm.p(4) =  200. + masp
+            first = .false.
+         endif
+         if( A /= Asave ) then
+            call ctotx0(proton, A, xst)
+            ratio = cPDGsigmaTotpA(A)/xst
+            Asave =  A
+         endif
+         xs = xs *ratio
+      endif
+      end
+
+      subroutine ctotx0(pj, A, xs)
+      implicit none
+#include "Zptcl.h"
+#include "Zcode.h"
 #include "Zevhnp.h"
       record /ptcl/pj   !input projectile particle
       real*8  A          ! input. effective target mass number
@@ -130,6 +166,11 @@ c          don't worry, not used almost at all; use proton
 c            shp = ctotpp1(p)
             call cppTotXs(p, shp)
             call cxp2xAXsec(A, shp, xs)               
+         elseif( pj.code == kgnuc ) then
+            write(0,*) 'Sorry: ctotx is not usable for heavy ions'
+            write(0,*) ' only inelastic xs is used for heavy ions'
+            write(0,*) ' so that you may use cinela or cAAXsec2'
+            stop
          else
 c          use pion
 c            shp =ctotpiPp1(p)
