@@ -1,6 +1,5 @@
-c//////////////! for softenning X distribution
-#include "cutptcl.f"    
-c//////////////
+#include "csoftenPiK.f"
+#include "cutptcl.f"
       subroutine xBgRun
       implicit none
 #include  "Zmaxdef.h"
